@@ -1,7 +1,7 @@
 package IPC::System::Options;
 
 our $DATE = '2015-06-26'; # DATE
-our $VERSION = '0.15'; # VERSION
+our $VERSION = '0.16'; # VERSION
 
 use strict;
 use warnings;
@@ -64,7 +64,7 @@ sub _system_or_backtick {
             unless ref($opts->{capture}) eq 'ARRAY';
     }
 
-    state $log = do { require Log::Any; Log::Any->get_logger } if $opts->{log};
+    $log ||= do { require Log::Any; Log::Any->get_logger } if $opts->{log};
 
     my $wa;
     my $res;
@@ -201,7 +201,7 @@ IPC::System::Options - Perl's system() and backtick/qx replacement/wrapper, with
 
 =head1 VERSION
 
-This document describes version 0.15 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2015-06-26.
+This document describes version 0.16 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2015-06-26.
 
 =head1 SYNOPSIS
 
